@@ -21,31 +21,18 @@
  */
 
 #define _GNU_SOURCE
-
-#include "config.h"
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
 #include <stdbool.h>
-#include <errno.h>
-#include <getopt.h>
-#include <termios.h>
-#include <assert.h>
-#include <limits.h>
+#include <stdlib.h>
 #include <unistd.h>
+#include <string.h>
+#include <assert.h>
+#include <errno.h>
 #include <regex.h>
 #include <glib.h>
-#include "options.h"
 #include "configfile.h"
-#include "misc.h"
-#include "options.h"
-#include "error.h"
 #include "print.h"
 #include "rs485.h"
-#include "timestamp.h"
-#include "alert.h"
+#include "misc.h"
 
 #define CONFIG_GROUP_NAME_DEFAULT "default"
 
@@ -196,7 +183,7 @@ static void config_parse_keys(GKeyFile *key_file, char *group)
     config_get_string(key_file, group, "exclude-drivers", &option.exclude_devices, NULL);
     config_get_string(key_file, group, "exclude-tids", &option.exclude_devices, NULL);
     config_get_bool(key_file, group, "no-reconnect", &option.no_reconnect);
-    config_get_bool(key_file, group, "local-echo", &option.no_reconnect);
+    config_get_bool(key_file, group, "local-echo", &option.local_echo);
     config_get_string(key_file, group, "input-mode", &string, "normal", "hex", "line", NULL);
     if (string != NULL)
     {
