@@ -20,25 +20,14 @@
  */
 
 #define _GNU_SOURCE  // For FNM_EXTMATCH
-#include "config.h"
-#include <ctype.h>
-#include <dirent.h>
-#include <regex.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include <sys/stat.h>
-#include <time.h>
-#include <errno.h>
 #include <sys/poll.h>
 #include <sys/wait.h>
-#include <termios.h>
 #include <fnmatch.h>
-#include "error.h"
+#include <regex.h>
+#include <errno.h>
 #include "print.h"
-#include "options.h"
 
 void delay(long ms)
 {
