@@ -22,10 +22,54 @@
 #pragma once
 
 #include <stdbool.h>
+#include <glib.h>
 
 #define LINE_HIGH true
 #define LINE_LOW false
 
+#define TOPOLOGY_ID_SIZE 4
+
+typedef enum
+{
+    FLOW_NONE,
+    FLOW_HARD,
+    FLOW_SOFT,
+} flow_t;
+
+typedef enum
+{
+    PARITY_NONE,
+    PARITY_ODD,
+    PARITY_EVEN,
+    PARITY_MARK,
+    PARITY_SPACE,
+} parity_t;
+
+typedef enum
+{
+    AUTO_CONNECT_DIRECT,
+    AUTO_CONNECT_NEW,
+    AUTO_CONNECT_LATEST,
+    AUTO_CONNECT_END,
+} auto_connect_t;
+
+typedef struct
+{
+    char *tid;
+    double uptime;
+    char *path;
+    char *driver;
+    char *description;
+} device_t;
+
+typedef struct
+{
+    int mask;
+    int value;
+    bool reserved;
+} tty_line_config_t;
+
+extern const char *device_name;
 extern bool interactive_mode;
 extern bool map_i_nl_cr;
 extern bool map_i_cr_nl;
@@ -39,7 +83,6 @@ void tty_wait_for_device(void);
 void list_serial_devices(void);
 void tty_input_thread_create(void);
 void tty_input_thread_wait_ready(void);
-void tty_line_set(int fd, int mask, bool value);
-void tty_line_toggle(int fd, int mask);
-void tty_line_config(int mask, bool value);
-void tty_line_config_apply(void);
+void tty_line_set(int fd, tty_line_config_t line_config[]);
+void tty_search(void);
+GList *tty_search_for_serial_devices(void);
